@@ -1,5 +1,6 @@
 from jinja2 import Environment, PackageLoader
 from pycobertura.utils import green, rangify, red
+from pycobertura.cobertura import CoberturaDiff
 from tabulate import tabulate
 
 
@@ -12,7 +13,7 @@ def get_class_summary_row(cobertura, class_name):
 
     row = [
         class_name,
-        cobertura.total_lines(class_name),
+        cobertura.total_statements(class_name),
         cobertura.total_misses(class_name),
         cobertura.line_rate(class_name),
         cobertura.missed_lines(class_name),
@@ -25,7 +26,7 @@ class Reporter(object):
         self.cobertura = cobertura
 
     def get_report_row_by_class(self, class_name):
-        total_lines = self.cobertura.total_lines(class_name)
+        total_lines = self.cobertura.total_statements(class_name)
         line_rate = self.cobertura.line_rate(class_name)
         total_misses = self.cobertura.total_misses(class_name)
         missed_lines = self.cobertura.missed_lines(class_name)
@@ -40,16 +41,9 @@ class Reporter(object):
 
         return row
 
-    def get_footer_row(self, lines):
-        total_statements = 0
-        total_misses = 0
-        line_rates = []
-
-        for class_name, total_lines, misses, line_rate, missed_lines in lines:
-            total_statements += total_lines
-            total_misses += misses
-            line_rates.append(line_rate)
-
+    def get_footer_row(self):
+        total_statements = self.cobertura.total_statements()
+        total_misses = self.cobertura.total_misses()
         total_line_rate = self.cobertura.line_rate()
 
         footer = [
@@ -69,7 +63,7 @@ class Reporter(object):
             row = get_class_summary_row(self.cobertura, class_name)
             lines.append(row)
 
-        footer = self.get_footer_row(lines)
+        footer = self.get_footer_row()
         lines.append(footer)
 
         return lines
@@ -117,6 +111,13 @@ class TextReporter(Reporter):
 
 
 class HtmlReporter(TextReporter):
+    def __init__(self, *args, **kwargs):
+        super(HtmlReporter, self).__init__(*args, **kwargs)
+
+    def get_source(self, class_name):
+        lines = self.cobertura.class_source(class_name)
+        status_map = {True: 'hit', False: 'miss', None: 'noop'}
+        return [(lno, src, status_map[status]) for lno, src, status in lines]
 
     def generate(self):
         lines = self.get_report_lines()
@@ -126,17 +127,23 @@ class HtmlReporter(TextReporter):
             formatted_row = self.format_row(row)
             formatted_lines.append(formatted_row)
 
+        sources = []
+        for class_name in self.cobertura.classes():
+            source = self.get_source(class_name)
+            filename = self.cobertura.filename(class_name)
+            sources.append((class_name, filename, source))
+
         template = env.get_template('html.jinja2')
         return template.render(
             lines=formatted_lines[:-1],
-            footer=formatted_lines[-1]
+            footer=formatted_lines[-1],
+            sources=sources
         )
 
 
 class DeltaReporter(object):
     def __init__(self, cobertura1, cobertura2):
-        self.cobertura1 = cobertura1
-        self.cobertura2 = cobertura2
+        self.differ = CoberturaDiff(cobertura1, cobertura2)
 
     def get_diff_line(self, line1, line2):
         if line1 is not None:
@@ -200,19 +207,10 @@ class DeltaReporter(object):
 
         return diff_line
 
-    def get_footer_row(self, lines):
-        total_statements = 0
-        total_misses = 0
-        line_rates = []
-
-        for class_name, total_lines, misses, line_rate, missed_lines in lines:
-            total_statements += total_lines
-            total_misses += misses
-            line_rates.append(line_rate)
-
-        total_line_rate1 = self.cobertura1.line_rate()
-        total_line_rate2 = self.cobertura2.line_rate()
-        total_line_rate = total_line_rate2 - total_line_rate1
+    def get_footer_row(self):
+        total_statements = self.differ.diff_total_statements()
+        total_misses = self.differ.diff_total_misses()
+        total_line_rate = self.differ.diff_line_rate()
 
         footer = [
             'TOTAL',
@@ -227,16 +225,16 @@ class DeltaReporter(object):
     def get_report_lines(self):
         lines = []
 
-        classes1 = self.cobertura1.classes()
-        classes2 = self.cobertura2.classes()
+        classes1 = self.differ.cobertura1.classes()
+        classes2 = self.differ.cobertura2.classes()
         all_classes = set(classes1).union(set(classes2))
         for class_name in sorted(all_classes):
-            row1 = get_class_summary_row(self.cobertura1, class_name)
-            row2 = get_class_summary_row(self.cobertura2, class_name)
+            row1 = get_class_summary_row(self.differ.cobertura1, class_name)
+            row2 = get_class_summary_row(self.differ.cobertura2, class_name)
             row = self.get_diff_line(row1, row2)
             lines.append(row)
 
-        footer = self.get_footer_row(lines)
+        footer = self.get_footer_row()
         lines.append(footer)
 
         return lines
@@ -298,6 +296,11 @@ class TextReporterDelta(DeltaReporter):
 
 
 class HtmlReporterDelta(TextReporterDelta):
+    def get_source(self, class_name):
+        lines = self.differ.class_source(class_name)
+        status_map = {True: 'hit', False: 'miss', None: 'noop'}
+        return [(lno, src, status_map[status]) for lno, src, status in lines]
+
     def format_row(self, row):
         class_name, total_lines, total_misses, line_rate, missed_lines = row
 
@@ -330,8 +333,15 @@ class HtmlReporterDelta(TextReporterDelta):
             formatted_row = self.format_row(row)
             formatted_lines.append(formatted_row)
 
+        sources = []
+        for class_name in self.differ.cobertura2.classes():
+            source = self.get_source(class_name)
+            filename = self.differ.cobertura2.filename(class_name)
+            sources.append((class_name, filename, source))
+
         template = env.get_template('html-delta.jinja2')
         return template.render(
             lines=formatted_lines[:-1],
-            footer=formatted_lines[-1]
+            footer=formatted_lines[-1],
+            sources=sources
         )
