@@ -1,7 +1,6 @@
 import mock
 
-
-SOURCE_FILE = 'tests/cobertura.xml'
+from .utils import make_cobertura
 
 
 def remove_style_tag(html):
@@ -13,12 +12,6 @@ def remove_style_tag(html):
     return html_nostyle
 
 
-def make_cobertura(xml_file=SOURCE_FILE):
-    from pycobertura import Cobertura
-    cobertura = Cobertura(xml_file)
-    return cobertura
-
-
 def test_report_row_by_class():
     from pycobertura.reporters import TextReporter
 
@@ -302,56 +295,98 @@ def test_html_report():
     <meta charset="UTF-8">
   </head>
   <body>
-    <table>
-      <thead>
-        <tr>
-          <th>Name</th>
-          <th>Stmts</th>
-          <th>Miss</th>
-          <th>Cover</th>
-          <th>Missing</th>
-        </tr>
-      </thead>
-      <tbody>
-        <tr>
-          <td>Main</td>
-          <td>11</td>
-          <td>0</td>
-          <td>100.00%</td>
-          <td></td>
-        </tr>
-        <tr>
-          <td>search.BinarySearch</td>
-          <td>12</td>
-          <td>1</td>
-          <td>91.67%</td>
-          <td>24</td>
-        </tr>
-        <tr>
-          <td>search.ISortedArraySearch</td>
-          <td>0</td>
-          <td>0</td>
-          <td>100.00%</td>
-          <td></td>
-        </tr>
-        <tr>
-          <td>search.LinearSearch</td>
-          <td>7</td>
-          <td>2</td>
-          <td>71.43%</td>
-          <td>19-24</td>
-        </tr>
-      </tbody>
-      <tfoot>
-        <tr>
-          <td>TOTAL</td>
-          <td>30</td>
-          <td>3</td>
-          <td>90.00%</td>
-          <td></td>
-        </tr>
-      </tfoot>
-    </table>
+    <div class="container">
+      <table class="u-full-width">
+        <thead>
+          <tr>
+            <th>Name</th>
+            <th>Stmts</th>
+            <th>Miss</th>
+            <th>Cover</th>
+            <th>Missing</th>
+          </tr>
+        </thead>
+        <tbody>
+          <tr>
+            <td><a href="#Main">Main</a></td>
+            <td>11</td>
+            <td>0</td>
+            <td>100.00%</td>
+            <td></td>
+          </tr>
+          <tr>
+            <td><a href="#search.BinarySearch">search.BinarySearch</a></td>
+            <td>12</td>
+            <td>1</td>
+            <td>91.67%</td>
+            <td>24</td>
+          </tr>
+          <tr>
+            <td><a href="#search.ISortedArraySearch">search.ISortedArraySearch</a></td>
+            <td>0</td>
+            <td>0</td>
+            <td>100.00%</td>
+            <td></td>
+          </tr>
+          <tr>
+            <td><a href="#search.LinearSearch">search.LinearSearch</a></td>
+            <td>7</td>
+            <td>2</td>
+            <td>71.43%</td>
+            <td>19-24</td>
+          </tr>
+        </tbody>
+        <tfoot>
+          <tr>
+            <td>TOTAL</td>
+            <td>30</td>
+            <td>3</td>
+            <td>90.00%</td>
+            <td></td>
+          </tr>
+        </tfoot>
+      </table>
+<h4 id="Main">Main</h4>
+<div class="row">
+  <div class="one column lineno">
+    <pre>0
+</pre>
+  </div>
+  <div class="eleven columns code">
+    <pre><span class="noop">Main.java not found</span></pre>
+  </div>
+</div>
+<h4 id="search.BinarySearch">search.BinarySearch</h4>
+<div class="row">
+  <div class="one column lineno">
+    <pre>0
+</pre>
+  </div>
+  <div class="eleven columns code">
+    <pre><span class="noop">search/BinarySearch.java not found</span></pre>
+  </div>
+</div>
+<h4 id="search.ISortedArraySearch">search.ISortedArraySearch</h4>
+<div class="row">
+  <div class="one column lineno">
+    <pre>0
+</pre>
+  </div>
+  <div class="eleven columns code">
+    <pre><span class="noop">search/ISortedArraySearch.java not found</span></pre>
+  </div>
+</div>
+<h4 id="search.LinearSearch">search.LinearSearch</h4>
+<div class="row">
+  <div class="one column lineno">
+    <pre>0
+</pre>
+  </div>
+  <div class="eleven columns code">
+    <pre><span class="noop">search/LinearSearch.java not found</span></pre>
+  </div>
+</div>
+    </div>
   </body>
 </html>"""
 
@@ -359,8 +394,8 @@ def test_html_report():
 def test_html_report_delta():
     from pycobertura.reporters import HtmlReporterDelta
 
-    cobertura1 = make_cobertura('tests/dummy.original-full-cov.xml')
-    cobertura2 = make_cobertura('tests/dummy.with-dummy2-no-cov.xml')
+    cobertura1 = make_cobertura('tests/dummy.source1.xml', base_path='tests/dummy.source1')
+    cobertura2 = make_cobertura('tests/dummy.source2.xml', base_path='tests/dummy.source2')
 
     report_delta = HtmlReporterDelta(cobertura1, cobertura2)
     html_output = report_delta.generate()
@@ -376,51 +411,102 @@ def test_html_report_delta():
     <meta charset="UTF-8">
   </head>
   <body>
-    <table>
-      <thead>
-        <tr>
-          <th>Name</th>
-          <th>Stmts</th>
-          <th>Miss</th>
-          <th>Cover</th>
-          <th>Missing</th>
-        </tr>
-      </thead>
-      <tbody>
-        <tr>
-          <td>dummy/__init__</td>
-          <td>-</td>
-          <td>-</td>
-          <td>-</td>
-          <td>
-          </td>
-        </tr>
-        <tr>
-          <td>dummy/dummy</td>
-          <td>-</td>
-          <td>-</td>
-          <td>-</td>
-          <td>
-          </td>
-        </tr>
-        <tr>
-          <td>dummy/dummy2</td>
-          <td>+2</td>
-          <td>+2</td>
-          <td>-</td>
-          <td><span class="red">+1</span>, <span class="red">+2</span>
-          </td>
-        </tr>
-      </tbody>
-      <tfoot>
-        <tr>
-          <td>TOTAL</td>
-          <td>+2</td>
-          <td>+2</td>
-          <td>-33.33%</td>
-          <td></td>
-        </tr>
-      </tfoot>
-    </table>
+    <div class="container">
+      <table class="u-full-width">
+        <thead>
+          <tr>
+            <th>Name</th>
+            <th>Stmts</th>
+            <th>Miss</th>
+            <th>Cover</th>
+            <th>Missing</th>
+          </tr>
+        </thead>
+        <tbody>
+          <tr>
+            <td><a href="#dummy/__init__">dummy/__init__</a></td>
+            <td>-</td>
+            <td>-</td>
+            <td>-</td>
+            <td>
+            </td>
+          </tr>
+          <tr>
+            <td><a href="#dummy/dummy">dummy/dummy</a></td>
+            <td>-</td>
+            <td>-2</td>
+            <td>+40.00%</td>
+            <td><span class="green">-5</span>, <span class="green">-6</span>
+            </td>
+          </tr>
+          <tr>
+            <td><a href="#dummy/dummy2">dummy/dummy2</a></td>
+            <td>+2</td>
+            <td>+1</td>
+            <td>-25.00%</td>
+            <td><span class="red">+5</span>
+            </td>
+          </tr>
+        </tbody>
+        <tfoot>
+          <tr>
+            <td>TOTAL</td>
+            <td>+2</td>
+            <td>-1</td>
+            <td>+17.46%</td>
+            <td></td>
+          </tr>
+        </tfoot>
+      </table>
+<h4 id="dummy/__init__">dummy/__init__</h4>
+<div class="row">
+  <div class="one column lineno">
+    <pre></pre>
+  </div>
+  <div class="eleven columns code">
+    <pre></pre>
+  </div>
+</div>
+<h4 id="dummy/dummy">dummy/dummy</h4>
+<div class="row">
+  <div class="one column lineno">
+    <pre>1
+2
+3
+4
+5
+6
+</pre>
+  </div>
+  <div class="eleven columns code">
+    <pre><span class="noop">def foo():
+</span><span class="noop">    pass
+</span><span class="noop">
+</span><span class="noop">def bar():
+</span><span class="hit">    a = &#39;a&#39;
+</span><span class="hit">    d = &#39;d&#39;
+</span></pre>
+  </div>
+</div>
+<h4 id="dummy/dummy2">dummy/dummy2</h4>
+<div class="row">
+  <div class="one column lineno">
+    <pre>1
+2
+3
+4
+5
+</pre>
+  </div>
+  <div class="eleven columns code">
+    <pre><span class="noop">def baz():
+</span><span class="hit">    c = &#39;c&#39;
+</span><span class="noop">
+</span><span class="hit">def bat():
+</span><span class="miss">    pass
+</span></pre>
+  </div>
+</div>
+    </div>
   </body>
 </html>"""
